@@ -29,15 +29,10 @@
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/EntityRightsFilterModel>
 #include <Akonadi/EntityTreeModel>
+#include <Akonadi/History>
 #include <Akonadi/ItemModifyJob>
 #include <Akonadi/ItemMoveJob>
 #include <Akonadi/Monitor>
-#include <akonadi_version.h>
-#if AKONADICALENDAR_VERSION > QT_VERSION_CHECK(5, 19, 41)
-#include <Akonadi/History>
-#else
-#include <Akonadi/Calendar/History>
-#endif
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 #include <EventViews/Prefs>
@@ -48,11 +43,6 @@
 #include <QPointer>
 #include <models/todosortfilterproxymodel.h>
 
-#if AKONADICALENDAR_VERSION > QT_VERSION_CHECK(5, 19, 41)
-#else
-#include <etmcalendar.h>
-#endif
-
 #include <colorproxymodel.h>
 #include <incidencewrapper.h>
 #include <sortedcollectionproxymodel.h>
@@ -148,11 +138,7 @@ protected:
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (role == Qt::ToolTipRole) {
-#if AKONADI_VERSION < QT_VERSION_CHECK(5, 20, 41)
-            const Akonadi::Collection col = CalendarSupport::collectionFromIndex(index);
-#else
             const Akonadi::Collection col = Akonadi::CollectionUtils::fromIndex(index);
-#endif
             return CalendarSupport::toolTipString(col);
         }
 
@@ -253,11 +239,7 @@ CalendarManager::CalendarManager(QObject *parent)
     auto refreshColors = [=]() {
         for (auto i = 0; i < m_flatCollectionTreeModel->rowCount(); i++) {
             auto idx = m_flatCollectionTreeModel->index(i, 0, {});
-#if AKONADI_VERSION < QT_VERSION_CHECK(5, 20, 41)
-            colorProxy->getCollectionColor(CalendarSupport::collectionFromIndex(idx));
-#else
             colorProxy->getCollectionColor(Akonadi::CollectionUtils::fromIndex(idx));
-#endif
         }
     };
     connect(m_flatCollectionTreeModel, &QSortFilterProxyModel::rowsInserted, this, refreshColors);
@@ -413,6 +395,14 @@ QVariant CalendarManager::getIncidenceSubclassed(KCalendarCore::Incidence::Ptr i
 
 QVariantMap CalendarManager::undoRedoData()
 {
+    if (!m_changer->history()) {
+        return {
+            {QStringLiteral("undoAvailable"), false},
+            {QStringLiteral("redoAvailable"), false},
+            {QStringLiteral("nextUndoDescription"), QString()},
+            {QStringLiteral("nextRedoDescription"), QString()},
+        };
+    }
     return QVariantMap{
         {QStringLiteral("undoAvailable"), m_changer->history()->undoAvailable()},
         {QStringLiteral("redoAvailable"), m_changer->history()->redoAvailable()},
@@ -438,6 +428,20 @@ KCalendarCore::Incidence::List CalendarManager::childIncidences(const QString &u
 
 void CalendarManager::addIncidence(IncidenceWrapper *incidenceWrapper)
 {
+    if (incidenceWrapper->collectionId() < 0) {
+        const auto sharedConfig = KSharedConfig::openConfig();
+        const auto editorConfigSection = sharedConfig->group("Editor");
+
+        const auto lastUsedCollectionType = incidenceWrapper->incidenceType() == KCalendarCore::IncidenceBase::TypeTodo
+            ? QStringLiteral("lastUsedTodoCollection")
+            : QStringLiteral("lastUsedEventCollection");
+        const auto lastUsedCollectionId = editorConfigSection.readEntry(lastUsedCollectionType, -1);
+
+        if (lastUsedCollectionId > -1) {
+            incidenceWrapper->setCollectionId(lastUsedCollectionId);
+        }
+    }
+
     Akonadi::Collection collection(incidenceWrapper->collectionId());
 
     switch (incidenceWrapper->incidencePtr()->type()) {
