@@ -7,11 +7,7 @@ TodoSortFilterProxyModel::TodoSortFilterProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
 {
     const QString todoMimeType = QStringLiteral("application/x-vnd.akonadi.calendar.todo");
-#if AKONADICALENDAR_VERSION < QT_VERSION_CHECK(5, 20, 41)
-    m_todoTreeModel = new IncidenceTreeModel(QStringList() << todoMimeType, this);
-#else
     m_todoTreeModel = new Akonadi::IncidenceTreeModel(QStringList() << todoMimeType, this);
-#endif
     const auto pref = EventViews::PrefsPtr(new EventViews::Prefs);
     m_baseTodoModel = new TodoModel(pref, this);
     m_baseTodoModel->setSourceModel(m_todoTreeModel);
@@ -92,11 +88,7 @@ QVariant TodoSortFilterProxyModel::data(const QModelIndex &index, int role) cons
     }
 
     auto collectionId = todoItem.parentCollection().id();
-#if AKONADICALENDAR_VERSION < QT_VERSION_CHECK(5, 20, 42)
-    auto todoPtr = CalendarSupport::todo(todoItem);
-#else
     auto todoPtr = Akonadi::CalendarUtils::todo(todoItem);
-#endif
 
     if (!todoPtr) {
         return {};
@@ -142,11 +134,7 @@ QVariant TodoSortFilterProxyModel::data(const QModelIndex &index, int role) cons
     } else if (role == Roles::IncidenceTypeIconRole) {
         return todoPtr->iconName();
     } else if (role == Roles::IncidencePtrRole) {
-#if AKONADICALENDAR_VERSION < QT_VERSION_CHECK(5, 20, 42)
-        return QVariant::fromValue(CalendarSupport::incidence(todoItem));
-#else
         return QVariant::fromValue(Akonadi::CalendarUtils::incidence(todoItem));
-#endif
     } else if (role == Roles::TagsRole) {
         return QVariant::fromValue(todoItem.tags());
     } else if (role == Roles::ItemRole) {
